@@ -7,17 +7,15 @@ package Comics::Plugin::AMultiverse;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.01";
+our $VERSION = "1.02";
 
 our $name    = "Scenes From A Multiverse";
-our $url     = "http://amultiverse.com/";
+our $url     = "https://amultiverse.com/";
 our $pattern =
-	    qr{ <div \s+ id="comic"> \s*
-		<img \s+
-		 src="(?<url>(?:http:)?//amultiverse.com/
+	    qr{ <meta \s+ property="og:image" \s+
+		 content="(?<url>(?:https?:)?//i\d.wp.com/amultiverse.com/
 		              wp-content/uploads/\d+/\d+/
-			      (?<image>.*?\.\w+))" \s+
-		 alt="(?<alt>.*?)"
+			      (?<image>.*?\.\w+))
 	      }six;
 
 # Important: Return the package name!
