@@ -7,7 +7,7 @@ package Comics::Plugin::Channelate;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.03";
+our $VERSION = "1.04";
 
 our $name    = "Channelate";
 our $url     = "http://channelate.com/";
@@ -15,7 +15,7 @@ our $url     = "http://channelate.com/";
 our $pattern =
   qr{ <div \s+ class="comic-table" > \s*
       <div \s+ id="comic" > \s*
-      <span \s+ class="comic-(?: tall | wide )" > \s*
+      <span \s+ class="comic-(?: tall | wide | square )" > \s*
       <img \s+
        src="(?<url>https?://www.channelate.com/wp-content/uploads/\d+/\d+/
              (?<image>.+?\.\w+))" \s+
