@@ -7,23 +7,23 @@ package Comics::Plugin::CommitStrip;
 
 use parent qw(Comics::Fetcher::Cascade);
 
-our $VERSION = "1.00";
+our $VERSION = "1.02";
 
 our $name     = "CommitStrip";
-our $url      = "http://www.commitstrip.com/en/";
+our $url      = "https://www.commitstrip.com/";
 our @patterns =
-	  ( qr{ <meta \s+
-		property="og:url" \s+
-		content="(?<url>.*?)"/>
+	  ( qr{ <a \s+
+		 href="(?<url>https://www.commitstrip.com/
+		     \d\d\d\d / \d\d / \d\d / .*? /)">
 	      }x,
 	    qr{ <img \s+
+		class="aligncenter \s+ size-full.*?" \s+
 		src="(?<url>https://www.commitstrip.com/wp-content/uploads/
 		       \d+/\d+/
 		       (?<image>.*?\.\w+))" \s+
 		alt="(?<alt>.*?)" \s+
 		width="\d+" \s+
-		height="\d+" \s+
-		class="alignnone \s+ size-full.*?" \s+ />
+		height="\d+" \s+ />
 	      }x
 	  );
 
