@@ -7,16 +7,15 @@ package Comics::Plugin::CyanideAndHappiness;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.00";
+our $VERSION = "1.01";
 
 our $name    = "Cyanide & Happiness (Explosm.net)";
-our $url     = "http://explosm.net/";
+our $url     = "https://explosm.net/";
 our $pattern =
 	    qr{ <img \s+
-		id="main-comic" \s+
-		src="(?<url>//files.explosm.net/comics/
-		(?:.+?/)?
-		(?<image>[^./]+\.\w+))
+		src="(?<url>https://static.explosm.net
+		    /\d+/\d+/\d+/
+		    (?<image>[^.]+\.\w+))
 	      }x;
 
 # Important: Return the package name!
