@@ -7,12 +7,12 @@ package Comics::Plugin::DoYouKnowFlo;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.04";
+our $VERSION = "1.05";
 
 our $name    = "Do you know Flo?";
 our $url     = "https://www.doyouknowflo.nl/";
 our $pattern =
-	    qr{ <img \s+
+	    qr{ <img \s+ (?:loading="lazy" \s+)?
 		 class="alignright \s+ wp-image-\d+ \s+ size-full" \s+
 		 src="(?<url>https?://doyouknowflo.nl/
 		        uploads/\d+/\d+/
